@@ -1,5 +1,4 @@
 /* -*- mode:C++; tab-width:8; c-basic-offset:8; indent-tabs-mode:true -*- */
-
 /*
  * written by J. Marcin Gorycki <marcin.gorycki@intel.com>
  *
@@ -20,29 +19,40 @@
  * For more details see the file COPYING.
  */
 
-#include "tetris.h"
-#include "field.h"
-#include "blockops.h"
-#include "blocks.h"
-#include "preview.h"
-#include "scoreframe.h"
-#include "highscores.h"
-#include "renderer.h"
-
-#include <games-frame.h>
-#include <games-controls.h>
-#include <games-stock.h>
-#include <games-sound.h>
-
-#include <libgnomevfs/gnome-vfs.h>
-
-#include <gdk/gdkkeysyms.h>
 #include <config.h>
+
 #include <dirent.h>
 #include <string.h>
 #include <math.h>
 #include <ctype.h>
 
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
+#include <gdk/gdkkeysyms.h>
+#include <gio/gio.h>
+
+#include <libgames-support/games-controls.h>
+#include <libgames-support/games-frame.h>
+#include <libgames-support/games-help.h>
+#include <libgames-support/games-runtime.h>
+#include <libgames-support/games-sound.h>
+#include <libgames-support/games-stock.h>
+
+#include "tetris.h"
+#include "blockops.h"
+#include "blocks.h"
+#include "scoreframe.h"
+#include "highscores.h"
+#include "renderer.h"
+
+#ifdef HAVE_CLUTTER
+#include "preview.h"
+#include "field.h"
+#else
+#include "preview-noclutter.h"
+#include "field-noclutter.h"
+#endif
+
 int LINES = 20;
 int COLUMNS = 14;
 
@@ -84,7 +94,7 @@ Tetris::Tetris(int cmdlLevel):
 	setupdialog(0), 
 	cmdlineLevel(cmdlLevel), 
 	fastFall(false),
-        dropBlock(false)
+	dropBlock(false)
 {
 	GtkUIManager *ui_manager;
 	GtkAccelGroup *accel_group;
@@ -94,6 +104,8 @@ Tetris::Tetris(int cmdlLevel):
 	GtkWidget *menubar;
 
 	gchar *outdir;
+	const char *dname;
+
 	const GtkTargetEntry targets[] = {{(gchar*) "text/uri-list", 0, URI_LIST}, 
 					  {(gchar*) "property/bgimage", 0, URI_LIST},
 					  {(gchar*) "text/plain", 0, TEXT_PLAIN},
@@ -141,8 +153,8 @@ Tetris::Tetris(int cmdlLevel):
 	
 
 	/* Locate our background image. */
-	outdir = g_build_filename (gnome_user_dir_get (), "gnometris.d", 
-				   NULL);
+
+	outdir = g_build_filename (g_get_user_data_dir (), "gnometris", NULL);
 	if (!g_file_test (outdir, G_FILE_TEST_EXISTS))
 	    mkdir (outdir, 0700);
 	bgPixmap = g_build_filename (outdir, "background.bin", NULL);
@@ -150,13 +162,14 @@ Tetris::Tetris(int cmdlLevel):
 
 	/*  Use default background image, if none found in user's home dir.*/
 	if (!g_file_test (bgPixmap, G_FILE_TEST_EXISTS)) {
-          defaultPixmap = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
-					        "pixmaps/gnometris/gnometris.svg",
-						 TRUE, NULL);
-	  default_bgimage = true;
+		dname = games_runtime_get_directory (GAMES_RUNTIME_GAME_PIXMAP_DIRECTORY);
+		defaultPixmap = g_build_filename (dname, "gnometris.svg", NULL);
+		default_bgimage = true;
 	}
 	
-	w = gnome_app_new("gnometris", _("Gnometris"));
+	w = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	gtk_window_set_title (GTK_WINDOW (w), _("Gnometris"));
+
 	g_signal_connect (w, "delete_event", G_CALLBACK (gameQuit), this);
 	gtk_drag_dest_set (w, GTK_DEST_DEFAULT_ALL, targets, 
 			   G_N_ELEMENTS(targets), 
@@ -170,7 +183,7 @@ Tetris::Tetris(int cmdlLevel):
 	line_fill_prob = 5;
 
 	gtk_window_set_default_size (GTK_WINDOW (w), DEFAULT_WIDTH, DEFAULT_HEIGHT);
-        games_conf_add_window (GTK_WINDOW (w), KEY_SAVED_GROUP);
+	games_conf_add_window (GTK_WINDOW (w), KEY_SAVED_GROUP);
 
 	preview = new Preview ();
 	field = new Field();
@@ -203,7 +216,7 @@ Tetris::Tetris(int cmdlLevel):
 	GtkWidget * hb = gtk_hbox_new(FALSE, 0);
 
 	vbox = gtk_vbox_new (FALSE, 0);
-	gnome_app_set_contents (GNOME_APP (w), vbox);
+	gtk_container_add (GTK_CONTAINER (w), vbox);
 	gtk_box_pack_start (GTK_BOX (vbox), menubar, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox), hb, TRUE, TRUE, 0);
 
@@ -216,14 +229,14 @@ Tetris::Tetris(int cmdlLevel):
 
 	GtkWidget *vb1 = gtk_vbox_new(FALSE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(vb1), 10);
-	gtk_box_pack_start_defaults(GTK_BOX(vb1), aspect_frame);
-	gtk_box_pack_start_defaults(GTK_BOX(hb), vb1);
+	gtk_box_pack_start(GTK_BOX(vb1), aspect_frame, TRUE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(hb), vb1, TRUE, TRUE, 0);
 
 	setupPixmap();
 
 	g_signal_connect (w, "key_press_event", G_CALLBACK (keyPressHandler), this);
 	g_signal_connect (w, "key_release_event", G_CALLBACK (keyReleaseHandler), this);
-  
+
 	GtkWidget *vb2 = gtk_vbox_new(FALSE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(vb2), 10);
 	gtk_box_pack_end(GTK_BOX(hb), vb2, 0, 0, 0);
@@ -236,10 +249,10 @@ Tetris::Tetris(int cmdlLevel):
 	high_scores = new HighScores ();
 
 	setOptions ();
-	setupScoreState ();
 
 	themeList = NULL;
 	
+	gtk_widget_show(vbox);
 	gtk_widget_show(hb);
 	gtk_widget_show(vb1);
 	gtk_widget_show(vb2);
@@ -252,10 +265,10 @@ Tetris::Tetris(int cmdlLevel):
 	gtk_action_set_sensitive(end_game_action, FALSE);
 	gtk_action_set_sensitive(preferences_action, TRUE);
 
-        confNotifyID = g_signal_connect (games_conf_get_default (),
-                                         "value-changed",
-                                         G_CALLBACK (confNotify),
-                                         this);
+	confNotifyID = g_signal_connect (games_conf_get_default (),
+					 "value-changed",
+					 G_CALLBACK (confNotify),
+					 this);
 }
 
 Tetris::~Tetris()
@@ -265,25 +278,15 @@ Tetris::~Tetris()
 	delete scoreFrame;
 
 	if (bgimage)
-		g_object_unref (G_OBJECT (bgimage));		
+		g_object_unref (G_OBJECT (bgimage));
 
 	if (bgPixmap)
 		g_free(bgPixmap);
 	if (defaultPixmap)
 		g_free(defaultPixmap);
 
-        if (confNotifyID != 0)
-                g_signal_handler_disconnect (games_conf_get_default (), confNotifyID);
-}
-
-void
-Tetris::setupScoreState ()
-{
-	if (high_scores->empty ()) {
-		gtk_action_set_sensitive (scores_action, FALSE);
-	} else {
-		gtk_action_set_sensitive (scores_action, TRUE);
-	}
+	if (confNotifyID != 0)
+		g_signal_handler_disconnect (games_conf_get_default (), confNotifyID);
 }
 
 void 
@@ -343,7 +346,7 @@ Tetris::setupPixmap()
 			int i, j;
 			
 			temp = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 
-					       bgwidth, bgheight); 
+						bgwidth, bgheight); 
 		
 			for (i=0; i<=bgwidth/width; i++) {
 				for (j=0; j<=bgheight/height; j++) {
@@ -382,8 +385,8 @@ Tetris::setupPixmap()
 void
 Tetris::confNotify (GamesConf *conf, const char *group, const char *key, gpointer data)
 {
-        if (!group)
-          return;
+	if (!group)
+		return;
 
 	Tetris *t = (Tetris *) data;
 
@@ -394,13 +397,13 @@ Tetris::confNotify (GamesConf *conf, const char *group, const char *key, gpointe
 char *
 Tetris::confGetString (const char *group, const char *key, const char *default_val)
 {
-        return games_conf_get_string_with_default (group, key, default_val);
+	return games_conf_get_string_with_default (group, key, default_val);
 }
 
 int
 Tetris::confGetInt (const char *group, const char *key, int default_val)
 {
-        return games_conf_get_integer_with_default (group, key, default_val);
+	return games_conf_get_integer_with_default (group, key, default_val);
 }
 
 gboolean
@@ -499,40 +502,40 @@ Tetris::setOptions ()
 void
 Tetris::setSound (GtkWidget *widget, gpointer data)
 {
-        games_conf_set_boolean (KEY_OPTIONS_GROUP, KEY_SOUND,
-			        GTK_TOGGLE_BUTTON (widget)->active);
+	games_conf_set_boolean (KEY_OPTIONS_GROUP, KEY_SOUND,
+				GTK_TOGGLE_BUTTON (widget)->active);
 }
 
 void 
 Tetris::setSelectionPreview(GtkWidget *widget, void *d)
 {
-        games_conf_set_boolean (KEY_OPTIONS_GROUP, KEY_DO_PREVIEW,
-			        GTK_TOGGLE_BUTTON (widget)->active);
+	games_conf_set_boolean (KEY_OPTIONS_GROUP, KEY_DO_PREVIEW,
+				GTK_TOGGLE_BUTTON (widget)->active);
 }
 
 void 
 Tetris::setSelectionBlocks(GtkWidget *widget, void *d)
 {
-        games_conf_set_boolean (KEY_OPTIONS_GROUP, KEY_RANDOM_BLOCK_COLORS,
-			        GTK_TOGGLE_BUTTON (widget)->active);
+	games_conf_set_boolean (KEY_OPTIONS_GROUP, KEY_RANDOM_BLOCK_COLORS,
+				GTK_TOGGLE_BUTTON (widget)->active);
 }
 
 void 
 Tetris::setRotateCounterClockWise(GtkWidget *widget, void *d)
 {
-        games_conf_set_boolean (KEY_OPTIONS_GROUP, KEY_ROTATE_COUNTER_CLOCKWISE,
-			        GTK_TOGGLE_BUTTON (widget)->active);
+	games_conf_set_boolean (KEY_OPTIONS_GROUP, KEY_ROTATE_COUNTER_CLOCKWISE,
+				GTK_TOGGLE_BUTTON (widget)->active);
 }
 
 void
 Tetris::setSelection(GtkWidget *widget, void *data)
 {
 	Tetris *t;
-      	t = (Tetris *)data;
+	t = (Tetris *)data;
 
 	t->themeno = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
 	t->field->setTheme (t->themeno);
-        games_conf_set_string (KEY_OPTIONS_GROUP, KEY_THEME,
+	games_conf_set_string (KEY_OPTIONS_GROUP, KEY_THEME,
 			       ThemeTable[t->themeno].id);
 }
 
@@ -545,88 +548,29 @@ Tetris::setTarget (GtkWidget *widget, void *data)
 
 	t->useTarget = GTK_TOGGLE_BUTTON (widget)->active;
 
-        games_conf_set_boolean (KEY_OPTIONS_GROUP, KEY_USE_TARGET, 
-			        t->useTarget);
+	games_conf_set_boolean (KEY_OPTIONS_GROUP, KEY_USE_TARGET, 
+				t->useTarget);
 }
 
 void
 Tetris::lineFillHeightChanged (GtkWidget *spin, gpointer data)
 {
 	gint value = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin));
-        games_conf_set_integer (KEY_OPTIONS_GROUP, KEY_LINE_FILL_HEIGHT, value);
+	games_conf_set_integer (KEY_OPTIONS_GROUP, KEY_LINE_FILL_HEIGHT, value);
 }
 
 void
 Tetris::lineFillProbChanged (GtkWidget *spin, gpointer data)
 {
 	gint value = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin));
-        games_conf_set_integer (KEY_OPTIONS_GROUP, KEY_LINE_FILL_PROBABILITY, value);
+	games_conf_set_integer (KEY_OPTIONS_GROUP, KEY_LINE_FILL_PROBABILITY, value);
 }
 
 void
 Tetris::startingLevelChanged (GtkWidget *spin, gpointer data)
 {
 	gint value = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin));
-        games_conf_set_integer (KEY_OPTIONS_GROUP, KEY_STARTING_LEVEL, value);
-}
-
-void
-Tetris::fillMenu(GtkWidget *menu, char *pixname, char *dirname, 
-		 GList ** listp, bool addnone /*= false*/)
-{
-	struct dirent *e;
-	char *dname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP, dirname, FALSE, NULL);
-	DIR *dir;
-	int itemno = 0;
-	GList * list;
-
-	list = *listp;
-
-	if (list) {
-		g_list_foreach (list, (GFunc) g_free, NULL);
-		g_list_free (list);
-		*listp = NULL;
-	}
-	
-	dir = opendir (dname);
-
-	if (!dir)
-		return;
-	
-	char *s;
-	
-	while ((e = readdir (dir)) != 0)
-	{
-		s = g_strdup(e->d_name);
-
-		if (!(strstr (e->d_name, ".png") || 
-		      strstr (e->d_name, ".jpg") ||
-		      strstr (e->d_name, ".svg"))) 
-		{
-			free(s);
-			continue;
-		}
-
-		gtk_combo_box_append_text (GTK_COMBO_BOX (menu), s);
-		*listp = g_list_append (*listp, s);
-			  
-		if (!strcmp(pixname, s))
-		{
-		  gtk_combo_box_set_active(GTK_COMBO_BOX (menu), itemno);
-		}
-		itemno++;
-	}
-	
-	if (addnone)
-	{
-        /* Translators: This is the placeholder item in the theme combo box
-           (preferences dialog) when no themes are available */
-		s = g_strdup(_("<none>"));
-		gtk_combo_box_append_text (GTK_COMBO_BOX (menu), _("<none>"));
-		*listp = g_list_append (*listp, s);
-	}
-	
-	closedir(dir);
+	games_conf_set_integer (KEY_OPTIONS_GROUP, KEY_STARTING_LEVEL, value);
 }
 
 int 
@@ -683,7 +627,7 @@ Tetris::gameProperties(GtkAction *action, void *d)
 	label = gtk_label_new_with_mnemonic (_("_Number of pre-filled rows:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
-	                  (GtkAttachOptions) GTK_FILL, 
+			  (GtkAttachOptions) GTK_FILL, 
 			  (GtkAttachOptions) 0,
 			  0, 0);
 
@@ -702,7 +646,7 @@ Tetris::gameProperties(GtkAction *action, void *d)
 	label = gtk_label_new_with_mnemonic (_("_Density of blocks in a pre-filled row:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
-	                  (GtkAttachOptions) GTK_FILL, 
+			  (GtkAttachOptions) GTK_FILL, 
 			  (GtkAttachOptions) 0,
 			  0, 0);
 
@@ -721,7 +665,7 @@ Tetris::gameProperties(GtkAction *action, void *d)
 	label = gtk_label_new_with_mnemonic (_("_Starting level:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3,
-	                  (GtkAttachOptions) GTK_FILL, 
+			  (GtkAttachOptions) GTK_FILL, 
 			  (GtkAttachOptions) 0,
 			  0, 0);
 
@@ -946,12 +890,12 @@ Tetris::timeoutHandler(void *d)
 	if (t->paused)
 		return TRUE;
 
- 	if (t->onePause)
- 	{
+	if (t->onePause)
+	{
 		t->onePause = false;
 		t->field->redraw();
 	}
- 	else
+	else
 	{
 		bool res = t->field->moveBlockDown();
 
@@ -1017,7 +961,7 @@ Tetris::keyPressHandler(GtkWidget *widget, GdkEvent *event, Tetris *t)
 			t->field->dropBlock();
 			t->manageFallen();
 			res = TRUE;
-		}        
+		}
 	}
 
 	t->field->redraw();
@@ -1056,11 +1000,11 @@ void Tetris::saveBgOptions ()
 {
 	gchar cbuffer[64];
 
-        games_conf_set_boolean (KEY_OPTIONS_GROUP, KEY_USE_BG_IMAGE, usebg);
+	games_conf_set_boolean (KEY_OPTIONS_GROUP, KEY_USE_BG_IMAGE, usebg);
 
 	g_snprintf (cbuffer, sizeof (cbuffer), "#%04x%04x%04x",
-                    bgcolour.red, bgcolour.green, bgcolour.blue);
-        games_conf_set_string (KEY_OPTIONS_GROUP, KEY_BG_COLOUR, cbuffer);
+		    bgcolour.red, bgcolour.green, bgcolour.blue);
+	games_conf_set_string (KEY_OPTIONS_GROUP, KEY_BG_COLOUR, cbuffer);
 }
 
 void
@@ -1087,7 +1031,7 @@ Tetris::resetColour (Tetris *t)
 	t->saveBgOptions ();
 }
 
-gchar * 
+char * 
 Tetris::decodeDropData(gchar * data, gint type)
 {
 	gchar *start, *end;
@@ -1129,16 +1073,20 @@ Tetris::dragDrop(GtkWidget *widget, GdkDragContext *context,
 		 gint x, gint y, GtkSelectionData *data, guint info, 
 		 guint time, Tetris * t)
 {
-	gchar * fileuri;
-	GnomeVFSHandle *inhandle;
-	GnomeVFSHandle *outhandle;
-	GnomeVFSResult result;
-	GnomeVFSFileInfo fileinfo;
-	GnomeVFSFileSize bytesread;
-	GnomeVFSFileSize filesize;
-	GdkPixbufLoader * loader;
-	GdkPixbuf * pixbuf;
-	guchar * buffer;
+	const char *fileuri;
+
+	GError *error;
+	GFile *file;
+	GFile *outfile;
+	GFileInfo *fileinfo;
+	GFileInputStream *istream;
+	GFileOutputStream *outstream;
+	goffset filesize;
+	gssize bytesread, byteswrote;
+
+	GdkPixbufLoader *loader;
+	GdkPixbuf *pixbuf;
+	guchar *buffer;
 
 
 	/* Accept a dropped filename and try and load it as the
@@ -1167,40 +1115,35 @@ Tetris::dragDrop(GtkWidget *widget, GdkDragContext *context,
 		return;
 	}
 
-	fileuri = decodeDropData ((gchar *)data->data, info);
+	fileuri = decodeDropData ((char *)data->data, info);
 	/* Silently ignore bad data. */
 	if (fileuri == NULL)
 		goto error_exit;
 
 	/* Now that we have a URI we load it and test it to see if it is 
 	 * an image file. */
-
-	/* FIXME: All this is slow and synchronous. It also
-	 * doesn't give any feedback about errors. */
 	
-	result = gnome_vfs_open (&inhandle, fileuri, GNOME_VFS_OPEN_READ);
-	if (result != GNOME_VFS_OK)
+	file = g_file_new_for_uri (fileuri);
+	istream = g_file_read (file, NULL, &error);
+
+	if (error)
 		goto error_exit;
 
-	result = gnome_vfs_get_file_info_from_handle (inhandle, &fileinfo,
-						      GNOME_VFS_FILE_INFO_FOLLOW_LINKS);
-	if (result != GNOME_VFS_OK)
+	fileinfo =  g_file_input_stream_query_info (istream, (char *)G_FILE_ATTRIBUTE_STANDARD_SIZE, NULL, &error);
+
+	if (error)
 		goto error_exit_handle;
 
-	/* This is where Drag and Drop of URLs from mozilla fails. */
-
-	if (!(fileinfo.valid_fields & GNOME_VFS_FILE_INFO_FIELDS_SIZE))
-		goto error_exit_handle;
-
-	filesize = fileinfo.size;
+	filesize = g_file_info_get_size (fileinfo);
 
 	buffer = (guchar *)g_malloc (filesize);
 	if (buffer == NULL)
 		goto error_exit_handle;
 	
-	result = gnome_vfs_read (inhandle, buffer, filesize, &bytesread);
+	bytesread = g_input_stream_read (G_INPUT_STREAM (istream), buffer, filesize, NULL, &error);
+
 	/* FIXME: We should reread if not enough was read. */
-	if ((result != GNOME_VFS_OK) || (bytesread != filesize))
+	if (error || (bytesread != filesize))
 		goto error_exit_buffer;
 
 	loader = gdk_pixbuf_loader_new ();
@@ -1220,27 +1163,33 @@ Tetris::dragDrop(GtkWidget *widget, GdkDragContext *context,
 	 * can handle. Now we save it to disk. This is necessary so that
 	 * "slow" URIs (e.g. http) behave well in the long run. */
 
-	result = gnome_vfs_create (&outhandle, t->bgPixmap, GNOME_VFS_OPEN_WRITE,
-				   FALSE, 0600);
-	if (result != GNOME_VFS_OK)
+	outfile = g_file_new_for_path (t->bgPixmap);
+	outstream = g_file_replace (outfile, NULL, FALSE, G_FILE_CREATE_PRIVATE,
+					NULL, &error);
+
+	if (error)
 		goto error_exit_loader;
 
-	result = gnome_vfs_write (outhandle, buffer, filesize, &bytesread);
-	if ((result != GNOME_VFS_OK) || (bytesread != filesize))
+	byteswrote = g_output_stream_write (G_OUTPUT_STREAM (outstream), buffer,
+						bytesread, NULL, &error);
+
+	if (byteswrote != filesize)
 	    goto error_exit_saver;
 
 	t->usebg = TRUE;
 	t->saveBgOptions ();
 
  error_exit_saver:
-	gnome_vfs_close (outhandle);
+	g_object_unref(outstream);
  error_exit_loader:
 	g_object_unref (loader);
  error_exit_buffer:
 	g_free (buffer);
  error_exit_handle:
-	gnome_vfs_close (inhandle);
+	g_object_unref(istream);
  error_exit:
+	if(error)
+		g_error_free(error);
 	return;
 }
 
@@ -1360,10 +1309,10 @@ Tetris::gameNew(GtkAction *action, void *d)
 }
 
 int
-Tetris::gameHelp(GtkAction *action, void *d)
+Tetris::gameHelp(GtkAction *action, void *data)
 {
-	gnome_help_display ("gnometris.xml", NULL, NULL);
-
+	Tetris *t = (Tetris*) data;
+	games_help_display(t->getWidget(), "gnometris", NULL);
 	return TRUE;
 }
 
@@ -1380,7 +1329,7 @@ Tetris::gameAbout(GtkAction *action, void *d)
 
 	gtk_show_about_dialog (GTK_WINDOW (t->getWidget()),
 #if GTK_CHECK_VERSION (2, 11, 0)
-                               "program-name", _("Gnometris"),
+			       "program-name", _("Gnometris"),
 #else
 			       "name", _("Gnometris"),
 #endif
@@ -1388,7 +1337,7 @@ Tetris::gameAbout(GtkAction *action, void *d)
 			       "comments", _("A classic game of fitting falling blocks together.\n\nGnometris is a part of GNOME Games."),
 			       "copyright", "Copyright \xc2\xa9 1999 J. Marcin Gorycki, 2000-2008 Others",
 			       "license", license,
-		               "website-label", _("GNOME Games web site"),
+			       "website-label", _("GNOME Games web site"),
 			       "authors", authors,
 			       "documenters", documenters,				
 			       "translator-credits", _("translator-credits"),
