@@ -33,17 +33,23 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
+#include <config.h>
+
+#include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
 #include <stdarg.h>
 
-#include <config.h>
-#include <gnome.h>
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
+#include <gdk/gdkkeysyms.h>
 
-#include <games-stock.h>
-#include <games-scores.h>
-#include <games-scores-dialog.h>
-#include <games-conf.h>
+#include <libgames-support/games-help.h>
+#include <libgames-support/games-stock.h>
+#include <libgames-support/games-scores.h>
+#include <libgames-support/games-scores-dialog.h>
+#include <libgames-support/games-conf.h>
+#include <libgames-support/games-runtime.h>
 
 #include "yahtzee.h"
 #include "gyahtzee.h"
@@ -55,12 +61,6 @@ static char *appName = N_("Tali");
 static guint last_timeout = 0;
 static gboolean ready_to_advance_player;
 
-#ifdef GNOMEPIXMAPDIR
-#define PP GNOMEPIXMAPDIR "/gtali/"
-#else
-#define PP ""
-#endif
-
 #define NUMBER_OF_PIXMAPS    7
 #define GAME_TYPES 2
 #define DIE_SELECTED_PIXMAP  (NUMBER_OF_PIXMAPS-1)
@@ -69,22 +69,22 @@ static gboolean ready_to_advance_player;
 #define DEFAULT_WIDTH 640
 #define DEFAULT_HEIGHT 480
 
-static char *dicefiles[NUMBER_OF_PIXMAPS] = { PP "gnome-dice-1.svg",
-  PP "gnome-dice-2.svg",
-  PP "gnome-dice-3.svg",
-  PP "gnome-dice-4.svg",
-  PP "gnome-dice-5.svg",
-  PP "gnome-dice-6.svg",
-  PP "gnome-dice-none.svg"
+static char *dicefiles[NUMBER_OF_PIXMAPS] = { "gnome-dice-1.svg",
+  "gnome-dice-2.svg",
+  "gnome-dice-3.svg",
+  "gnome-dice-4.svg",
+  "gnome-dice-5.svg",
+  "gnome-dice-6.svg",
+  "gnome-dice-none.svg"
 };
 
-static char *kdicefiles[NUMBER_OF_PIXMAPS] = { PP "kismet1.svg",
-  PP "kismet2.svg",
-  PP "kismet3.svg",
-  PP "kismet4.svg",
-  PP "kismet5.svg",
-  PP "kismet6.svg",
-  PP "kismet-none.svg"
+static char *kdicefiles[NUMBER_OF_PIXMAPS] = { "kismet1.svg",
+  "kismet2.svg",
+  "kismet3.svg",
+  "kismet4.svg",
+  "kismet5.svg",
+  "kismet6.svg",
+  "kismet-none.svg"
 };
 
 static GtkWidget *dicePixmaps[NUMBER_OF_DICE][NUMBER_OF_PIXMAPS][GAME_TYPES];
@@ -133,10 +133,9 @@ GamesScores *highscores;
 
 static GtkWidget *dialog = NULL;
 
-static gint gnome_modify_dice (GtkWidget * widget, gpointer data);
-static gint gnome_roll_dice (GtkWidget * widget, GdkEvent * event,
+static gint modify_dice (GtkWidget * widget, gpointer data);
+static gint roll_dice (GtkWidget * widget, GdkEvent * event,
 			     gpointer data);
-void update_score_state (void);
 static void UpdateRollLabel (void);
 
 static void
@@ -215,8 +214,6 @@ CheerWinner (void)
       gtk_dialog_run (GTK_DIALOG (dialog));
       gtk_widget_hide (dialog);
     }
-
-    update_score_state ();
   }
 
   if (players[winner].name)
@@ -533,7 +530,7 @@ DeselectAllDice (void)
 
 /* Callback on dice press */
 gint
-gnome_modify_dice (GtkWidget * widget, gpointer data)
+modify_dice (GtkWidget * widget, gpointer data)
 {
   DiceInfo *tmp = (DiceInfo *) data;
   GtkToggleToolButton *button = GTK_TOGGLE_TOOL_BUTTON (widget);
@@ -562,7 +559,7 @@ gnome_modify_dice (GtkWidget * widget, gpointer data)
 
 /* Callback on Roll! button press */
 gint
-gnome_roll_dice (GtkWidget * widget, GdkEvent * event, gpointer data)
+roll_dice (GtkWidget * widget, GdkEvent * event, gpointer data)
 {
   if (!players[CurrentPlayer].comp) {
     RollSelectedDice ();
@@ -661,29 +658,32 @@ static void
 LoadDicePixmaps (void)
 {
   int i, j;
+  char *path, *path_kismet;
+  const char *dir;
+
+  dir = games_runtime_get_directory (GAMES_RUNTIME_GAME_PIXMAP_DIRECTORY);
 
   for (i = 0; i < NUMBER_OF_PIXMAPS; i++) {
     /* This is not efficient, but it lets us load animated types,
      * there is no way for us to copy a general GtkImage (the old 
      * code had a way for static images). */
-    if (g_file_test (dicefiles[i], G_FILE_TEST_EXISTS))
+    path = g_build_filename (dir, dicefiles[i], NULL);
+    path_kismet = g_build_filename (dir, kdicefiles[i], NULL);
+
+    if (g_file_test (path, G_FILE_TEST_EXISTS) && 
+          g_file_test (path_kismet, G_FILE_TEST_EXISTS)) {
+
       for (j = 0; j < NUMBER_OF_DICE; j++) {
-        dicePixmaps[j][i][GAME_YAHTZEE] = gtk_image_new_from_file (dicefiles[i]);
-        dicePixmaps[j][i][GAME_KISMET] = gtk_image_new_from_file (kdicefiles[i]);
+        dicePixmaps[j][i][GAME_YAHTZEE] = gtk_image_new_from_file (path);
+        dicePixmaps[j][i][GAME_KISMET] = gtk_image_new_from_file (path_kismet);
       }
-    /* FIXME: What happens if the file isn't found. */
+
+    } /* FIXME: What happens if the file isn't found. */
+    g_free(path);
+    g_free(path_kismet);
   }
 }
 
-void
-update_score_state (void)
-{
-  GList *top;
-
-  top = games_scores_get (highscores);
-  gtk_action_set_sensitive (scores_action, top != NULL);
-}
-
 void
 update_undo_sensitivity (void)
 {
@@ -693,7 +693,7 @@ update_undo_sensitivity (void)
 static void
 help_cb (GtkAction * action, gpointer data)
 {
-  gnome_help_display ("gtali.xml", NULL, NULL);
+  games_help_display (window, "gtali", NULL);
 }
 
 
@@ -713,7 +713,7 @@ static const GtkActionEntry action_entry[] = {
   {"Contents", GAMES_STOCK_CONTENTS, NULL, NULL, NULL, G_CALLBACK (help_cb)},
   {"About", GTK_STOCK_ABOUT, NULL, NULL, NULL, G_CALLBACK (about_cb)},
   /* Roll is just an accelerator */
-  {"Roll", GTK_STOCK_REFRESH, NULL, "r", NULL, G_CALLBACK (gnome_roll_dice)}
+  {"Roll", GTK_STOCK_REFRESH, NULL, "r", NULL, G_CALLBACK (roll_dice)}
 };
 
 
@@ -766,7 +766,8 @@ GyahtzeeCreateMainWindow (void)
   GtkUIManager *ui_manager;
   int i, j;
 
-  window = gnome_app_new (appID, appName);
+  window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+  gtk_window_set_title (GTK_WINDOW (window), _(appName));
 
   gtk_window_set_default_size (GTK_WINDOW (window), DEFAULT_WIDTH, DEFAULT_HEIGHT);
   games_conf_add_window (GTK_WINDOW (window), NULL);
@@ -793,12 +794,12 @@ GyahtzeeCreateMainWindow (void)
   hbox = gtk_hbox_new (FALSE, 0);
   vbox = gtk_vbox_new (FALSE, 0);
 
+  gtk_container_add (GTK_CONTAINER (window), vbox);
+
   gtk_box_pack_start (GTK_BOX (vbox), menubar, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), statusbar, FALSE, FALSE, 0);
 
-  gnome_app_set_contents (GNOME_APP (window), vbox);
-
   gtk_widget_show (statusbar);
   /* Retreive dice pixmaps from memory or files */
   LoadDicePixmaps ();
@@ -816,7 +817,7 @@ GyahtzeeCreateMainWindow (void)
   mbutton = gtk_button_new_with_label (_("Roll!"));
   gtk_box_pack_end (GTK_BOX (dicebox), mbutton, FALSE, FALSE, 5);
   g_signal_connect (G_OBJECT (mbutton), "clicked",
-		    G_CALLBACK (gnome_roll_dice), NULL);
+		    G_CALLBACK (roll_dice), NULL);
   gtk_widget_show (GTK_WIDGET (mbutton));
 
   toolbar = gtk_toolbar_new ();
@@ -837,7 +838,7 @@ GyahtzeeCreateMainWindow (void)
     diceBox[i] = gtk_toggle_tool_button_new ();
     gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (diceBox[i]), tmp);
     g_signal_connect (G_OBJECT (diceBox[i]), "clicked",
-		      G_CALLBACK (gnome_modify_dice), &DiceValues[i]);
+		      G_CALLBACK (modify_dice), &DiceValues[i]);
 
     gtk_toolbar_insert (GTK_TOOLBAR (toolbar),
 			GTK_TOOL_ITEM (diceBox[i]), -1);
@@ -855,26 +856,29 @@ GyahtzeeCreateMainWindow (void)
   gtk_widget_show (ScoreList);
 
   gtk_widget_show (hbox);
+  gtk_widget_show (vbox);
 
   gtk_widget_show (window);
-
-  update_score_state ();
-
 }
 
 int
 main (int argc, char *argv[])
 {
-  GnomeProgram *program;
   char **player_names;
   gsize n_player_names;
   guint i;
   GOptionContext *context;
+  gboolean retval;
+  GError *error = NULL;
 
   g_thread_init (NULL);
 
+  if (!games_runtime_init ("gtali"))
+    return 1;
+
   setgid_io_init ();
-  bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+
+  bindtextdomain (GETTEXT_PACKAGE, games_runtime_get_directory (GAMES_RUNTIME_LOCALE_DIRECTORY));
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
@@ -882,15 +886,18 @@ main (int argc, char *argv[])
   YahtzeeInit ();
 
   context = g_option_context_new (NULL);
+  g_option_context_add_group (context, gtk_get_option_group (TRUE));
   g_option_context_add_main_entries (context, yahtzee_options,
 				     GETTEXT_PACKAGE);
+  retval = g_option_context_parse (context, &argc, &argv, &error);
+  g_option_context_free (context);
+  if (!retval) {
+    g_print ("%s", error->message);
+    g_error_free (error);
+    exit (1);
+  }
 
-  /* Create gnome client */
-  program = gnome_program_init (appID, VERSION,
-				LIBGNOMEUI_MODULE,
-				argc, argv,
-				GNOME_PARAM_GOPTION_CONTEXT, context,
-				GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
+  g_set_application_name (_(appName));
 
   games_conf_initialise (appID);
 
@@ -1007,7 +1014,7 @@ main (int argc, char *argv[])
 
   games_conf_shutdown ();
 
-  g_object_unref (program);
+  games_runtime_shutdown ();
 
   exit(0);
 }
